interminebio.SequenceDataQuery

Package interminebio :: Class SequenceDataQuery |
[hide private]
[frames] | no frames]

# Class SequenceDataQuery

source code

    object --+
             |
            SequenceDataQuery

Known Subclasses:
  - RegionQuery
  - , SequenceQuery

Instance Methods | [hide private]
bed(self, ucsc_compatible=True) Return a BedIterator object, which stringifies to the BED results, and works as an iterator over the lines. | source code
fasta(self) Return a FastaIterator object, which stringifies to the Fasta results, and works as an iterator over the records (not the lines). | source code
gff3(self) Return a GFF3Iterator object, which stringifies to the GFF3 results, and works as an iterator over the lines. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### bed(self, ucsc_compatible=True) | source code
# Get results as BED Return a BedIterator object, which stringifies to the BED results, and works as an iterator over the lines. After iteration the header information is accessible with the iter.header() method

### fasta(self) | source code
# Get results as FASTA Return a FastaIterator object, which stringifies to the Fasta results, and works as an iterator over the records (not the lines). When attempting to get results as FASTA the query may only have a single output column. Errors will be raised otherwise.

### gff3(self) | source code
# Get results as GFF3 Return a GFF3Iterator object, which stringifies to the GFF3 results, and works as an iterator over the lines. After iteration the header information is accessible with the iter.header() method